/**
 * Base path from which test resources are loaded.
 * @hidden
 */
export declare const testResourcesRoot: string;
/**
 * Get URL of test resource.
 *
 * Calculates URL of test resource in same way as [[loadTestResource]].
 *
 * @param moduleName -: module name, `@here/<module_name>` (e.g. @here/harp-vectortile-datasource)
 * @param fileName -: file relative to module path (e.g. `test/resources/berlin.bin)`
 */
export declare function getTestResourceUrl(module: string, fileName: string): string;
/**
 * Function which runs a cross-environment resource loader which gets the static resources
 * requested. (e.g. needed for tests purposes).
 *
 * The following folders are mapped in test environment for resources that are needed for testing
 * purposes:
 *  * `@here/${module}/test/resources`
 *  * `@here/${module}/resources`
 *
 * The `fileName` must be relative to package root.
 *
 * Exemplary methods invocation:
 * ```
 * const binaryData = await loadTestResourceWeb('test-utils', 'test/resources/test.bin', 'binary');
 *
 * const textData = await  loadTestResourceWeb('test-utils', 'test/resources/test.txt', 'text');
 *
 * const theme = await loadTestResource('map-theme', 'resources/berlin_tilezen_base.json', 'json');
 * ```
 *
 * These locations above are mapped in the same way regardless of the runtime environment used
 * (node.js or browser).
 *
 * Internally this function loads resources in an environment-agnostic way, using the following:
 *
 *   * `fs` module when run in a node.js environment
 *   * `fetch` module when run in a browser environment
 *
 * @param module -: module name, @here/<module_name> (e.g. @here/harp-vectortile-datasource)
 * @param fileName -: the requested resource
 *                  (e.g. @here/harp-vectortile-datasource/test/resources/berlin.bin)
 */
export declare const loadTestResource: typeof loadTestResourceWeb;
/** @hidden */
export declare function loadTestResourceWeb(module: string, fileName: string, type: "arraybuffer"): Promise<ArrayBuffer>;
/** @hidden */
export declare function loadTestResourceWeb(module: string, fileName: string, type: "text"): Promise<string>;
/** @hidden */
export declare function loadTestResourceWeb(module: string, fileName: string, type: "json"): Promise<any>;
//# sourceMappingURL=TestDataUtils.web.d.ts.map