"use strict";
/*
 * Copyright (C) 2019-2021 HERE Europe B.V.
 * Licensed under Apache 2.0, see full license in LICENSE
 * SPDX-License-Identifier: Apache-2.0
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.DomReporter = void 0;
const DomImageUtils_1 = require("./DomImageUtils");
const Magnifier_1 = require("./Magnifier");
const RenderingTestHelper_1 = require("./RenderingTestHelper");
/**
 * Reports IBCT test results as simple table attached to end of `document.body`.
 *
 * Use in 'developer' testing, possibly with test suite filtered for work-in-progress tests with
 * `.only`. The test images (actual, current, diff) are shown in browser.
 */
class DomReporter {
    constructor() {
        this.m_headerReported = false;
    }
    reportImageComparisonResult(imageProps, actualImage, passed, referenceImage, // server already has reference image
    comparisonResult) {
        this.addHeaderIfNeeded();
        const diff = this.reportImageComparisonDOM(actualImage, referenceImage, comparisonResult && comparisonResult.diffImage);
        document.body.appendChild(document.createElement("hr"));
        const mismatchedPixels = comparisonResult ? `: ${comparisonResult.mismatchedPixels}` : "";
        const imageTitle = Object.keys(imageProps)
            .reduce((r, key) => {
            r.push(`${key}=${imageProps[key]}`);
            return r;
        }, [])
            .join(" / ");
        document.body.appendChild(document.createTextNode(`IBCT ${imageTitle}: ${mismatchedPixels}`));
        document.body.appendChild(diff);
    }
    reportImageComparisonDOM(actual, expected, diff) {
        const parent = document.createElement("div");
        parent.style.display = "flex";
        parent.style.justifyContent = "space-around";
        parent.className = "image-comparison-result";
        const group1 = document.createElement("div");
        group1.style.flex = "1";
        group1.appendChild(document.createTextNode("Actual"));
        const actualImg = DomImageUtils_1.createImgElement(actual);
        actualImg.style.width = "100%";
        actualImg.style.height = "auto";
        actualImg.style.border = "1px solid grey";
        actualImg.style.imageRendering = "pixelated";
        actualImg.className = "actual";
        group1.appendChild(actualImg);
        const group2 = document.createElement("div");
        group2.style.flex = "1";
        group2.appendChild(document.createTextNode("Reference"));
        const expectedImg = expected ? DomImageUtils_1.createImgElement(expected) : document.createElement("img");
        expectedImg.className = "expected";
        expectedImg.style.width = "100%";
        expectedImg.style.height = "auto";
        expectedImg.style.border = "1px solid grey";
        expectedImg.style.imageRendering = "pixelated";
        group2.appendChild(expectedImg);
        const group3 = document.createElement("div");
        group3.style.flex = "1";
        group3.appendChild(document.createTextNode("Difference"));
        const diffImg = diff ? DomImageUtils_1.createImgElement(diff) : document.createElement("img");
        diffImg.className = "diff";
        diffImg.style.width = "100%";
        diffImg.style.height = "auto";
        diffImg.style.border = "1px solid grey";
        diffImg.style.imageRendering = "pixelated";
        group3.appendChild(diffImg);
        parent.appendChild(group1);
        parent.appendChild(group2);
        parent.appendChild(group3);
        Magnifier_1.installMagnifier(actualImg, expectedImg, diffImg);
        return parent;
    }
    addHeaderIfNeeded() {
        if (this.m_headerReported) {
            return;
        }
        const header = document.createElement("div");
        const webGLInfo = RenderingTestHelper_1.getWebGlInfo();
        header.innerHTML = `
            WebGL.vendor = ${webGLInfo.vendor}<br>
            WebGL.gpu = ${webGLInfo.gpu}
        `;
        document.body.appendChild(header);
        this.m_headerReported = true;
    }
}
exports.DomReporter = DomReporter;
//# sourceMappingURL=DomReporter.js.map