"use strict";
/*
 * Copyright (C) 2019-2021 HERE Europe B.V.
 * Licensed under Apache 2.0, see full license in LICENSE
 * SPDX-License-Identifier: Apache-2.0
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.getOverride = exports.setReferenceImageResolver = exports.defaultReferenceImageResolver = exports.getReferenceImageUrl = void 0;
const querystring = require("querystring");
let referenceImageResovler = defaultReferenceImageResolver;
/**
 * Get URL of reference image.
 *
 * Uses resolver set by [[setReferenceImageResolver]], by default, use
 * [[defaultReferenceImageResolver]].
 */
function getReferenceImageUrl(imageProps) {
    return referenceImageResovler(imageProps);
}
exports.getReferenceImageUrl = getReferenceImageUrl;
/**
 * Default reference image resolver URL of reference image.
 *
 * Relative to `baseUrl` of test runner page, which is usually `test/rendering.html`,
 * so relative to `mapsdk/test`.
 */
function defaultReferenceImageResolver(imageProps) {
    if (imageProps.name && imageProps.module) {
        const queryString = Object.keys(imageProps)
            .map(key => {
            return `${encodeURIComponent(key)}=${encodeURIComponent(imageProps[key])}`;
        })
            .join("&");
        return `/reference-image?${queryString}`;
    }
    else {
        throw new Error("unsupported test images props");
    }
}
exports.defaultReferenceImageResolver = defaultReferenceImageResolver;
function setReferenceImageResolver(resolver) {
    referenceImageResovler = resolver;
}
exports.setReferenceImageResolver = setReferenceImageResolver;
function getOverride(name, defaultValue) {
    if (typeof window !== "undefined" && window.location) {
        if (window.location.search) {
            const queryParams = querystring.parse(window.location.search.substr(1));
            if (queryParams[name] !== undefined) {
                return queryParams[name];
            }
        }
    }
    const windowOverride = global[name];
    if (windowOverride !== undefined) {
        return windowOverride;
    }
    return defaultValue;
}
exports.getOverride = getOverride;
//# sourceMappingURL=ReferenceImageLocator.js.map