/// <reference types="mocha" />
import { Reporter, TestImageProps } from "./Interface";
/**
 * Specifies how sensitive image comparison should be
 */
export interface TestOptions {
    /**
     * Defines how many pixels can mismatch. If more than maxMismatchedPixels
     * test fails.
     */
    maxMismatchedPixels?: number;
    /**
     * Matching threshold, ranges from 0 to 1.
     * Smaller values make the comparison more sensitive. 0 by default.
     * 0 - accepts perfect match, 1 - accepts many differences
     * Used with pixelmatch library: https://github.com/mapbox/pixelmatch
     */
    threshold?: number;
}
/**
 * Get `platform` property.
 *
 * Reads platform from:
 *  - query param `IBCT_PLATFORM_OVERRIDE` - overrides any detection
 *  - `navigator.userAgent` in form $name-$version-$os, optionally adds query param
 * `IBCT_PLATATFORM_EXTRA`
 *
 * `IBCT_PLATATFORM_EXTRA` is intended to inform about platform properties not detecatble from
 * browser api like "no-gpu" or "headless" or "-nvidia-gtx-whatever".
 */
export declare function getPlatform(): string;
export declare function setGlobalReporter(reporter: Reporter): void;
export declare class RenderingTestHelper {
    mochaTest: Mocha.Context;
    baseImageProps: TestImageProps;
    /**
     * Load image data using cache.
     */
    static cachedLoadImageData(url: string): Promise<ImageData>;
    private static readonly preloadedImageCache;
    constructor(mochaTest: Mocha.Context, baseImageProps: TestImageProps);
    /**
     * Save actual image only with comparison status OK
     *
     * @param canvas - actual image canvas
     * @param name - test name
     */
    saveCanvasMatchesReference(canvas: HTMLCanvasElement, name: string): Promise<void>;
    /**
     * Compare actual image vs reference image then report comparison result to feedbackServer
     *
     * @param canvas - actual image canvas
     * @param name - test name
     * @param options - test options
     */
    assertCanvasMatchesReference(canvas: HTMLCanvasElement, name: string, options?: TestOptions): Promise<void>;
}
interface WebGlInfo {
    vendor?: string;
    gpu?: string;
}
export declare function getWebGlInfo(): WebGlInfo;
export {};
//# sourceMappingURL=RenderingTestHelper.d.ts.map