"use strict";
/*
 * Copyright (C) 2019-2021 HERE Europe B.V.
 * Licensed under Apache 2.0, see full license in LICENSE
 * SPDX-License-Identifier: Apache-2.0
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.RenderingTestResultReporter = void 0;
const harp_utils_1 = require("@here/harp-utils");
const DomImageUtils_1 = require("./DomImageUtils");
const logger = harp_utils_1.LoggerManager.instance.create("RenderingTestResultReporter");
/**
 * Rpoerts IBCT test images to `FeedbackServer`.
 */
class RenderingTestResultReporter {
    constructor(backendUrl) {
        this.backendUrl = backendUrl;
    }
    reportImageComparisonResult(imageProps, actualImage, passed, _referenceImage, // server already has reference image
    comparisonResult) {
        const url = `${this.backendUrl}/ibct-feedback`;
        const payload = {
            imageProps,
            actualImage: DomImageUtils_1.imageDataToDataUrl(actualImage),
            passed,
            comparisonResult: comparisonResult
                ? {
                    mismatchedPixels: comparisonResult.mismatchedPixels,
                    diffImage: DomImageUtils_1.imageDataToDataUrl(comparisonResult.diffImage)
                }
                : undefined
        };
        const requestPayload = JSON.stringify(payload);
        const headers = new Headers();
        headers.set("Content-type", "application/json");
        fetch(url, { method: "POST", headers, body: requestPayload })
            .then(() => {
            // just ignore success
        })
            .catch(error => {
            logger.error(`failed to store actual image for report on server: ${error}`);
        });
    }
}
exports.RenderingTestResultReporter = RenderingTestResultReporter;
//# sourceMappingURL=RenderingTestResultReporter.js.map